==> diff2html-4.0.14.tgz: package/src/utils.js <==
/*
 *
 * Utils (utils.js)
 * Author: rtfpessoa
 *
 */

(function() {
  var merge = require('merge');

  function Utils() {
  }

  Utils.prototype.escape = function(str) {
    return str.slice(0)
      .replace(/&/g, '&amp;')
      .replace(/</g, '&lt;')
      .replace(/>/g, '&gt;')
      .replace(/"/g, '&quot;')
      .replace(/'/g, '&#x27;')
      .replace(/\//g, '&#x2F;')
      .replace(/\$/g, '&#x24;')
      .replace(/`/g, '&#x60;');
  };

  Utils.prototype.startsWith = function(str, start) {
    if (typeof start === 'object') {
      var result = false;
      start.forEach(function(s) {
        if (str.indexOf(s) === 0) {
          result = true;
        }
      });

      return result;
    }

    return str && str.indexOf(start) === 0;
  };

  Utils.prototype.valueOrEmpty = function(value) {
    return value || '';
  };

  Utils.prototype.safeConfig = function(cfg, defaultConfig) {
    return merge.recursive(true, defaultConfig, cfg);
  };

  Utils.prototype.getOverallLineCoverageRate = function(coverage) {
    let coveredLines = 0;
    let uncoveredLines = 0;
    for (const fileName in coverage) {
      const fileCoverageData = coverage[fileName];
      for (const lineNumber in fileCoverageData.lineMap) {
        const lineCoverageData = fileCoverageData.lineMap[lineNumber];
        if (lineCoverageData.hits > 0) {
          coveredLines += 1;
        } else {
          uncoveredLines += 1;
        }
      }
    }
    if (coveredLines + uncoveredLines === 0) {
      return null;
    } else {
      return parseFloat((coveredLines / (coveredLines + uncoveredLines) * 100).toFixed(2));
    }
  };

  module.exports.Utils = new Utils();
})();

==> diff2html-4.3.0.tgz: package/src/utils.js <==
/*
 *
 * Utils (utils.js)
 * Author: rtfpessoa
 *
 */

(function() {
  var merge = require('merge');
  var path = require('path');

  function Utils() {
  }

  Utils.prototype.escape = function(str) {
    return str.slice(0)
      .replace(/&/g, '&amp;')
      .replace(/</g, '&lt;')
      .replace(/>/g, '&gt;')
      .replace(/"/g, '&quot;')
      .replace(/'/g, '&#x27;')
      .replace(/\//g, '&#x2F;')
      .replace(/\$/g, '&#x24;')
      .replace(/`/g, '&#x60;');
  };

  Utils.prototype.startsWith = function(str, start) {
    if (typeof start === 'object') {
      var result = false;
      start.forEach(function(s) {
        if (str.indexOf(s) === 0) {
          result = true;
        }
      });

      return result;
    }

    return str && str.indexOf(start) === 0;
  };

  Utils.prototype.valueOrEmpty = function(value) {
    return value || '';
  };

  Utils.prototype.safeConfig = function(cfg, defaultConfig) {
    return merge.recursive(true, defaultConfig, cfg);
  };

  Utils.prototype.getOverallLineCoverageRate = function(coverage) {
    let coveredLines = 0;
    let uncoveredLines = 0;
    for (const fileName in coverage) {
      const fileCoverageData = coverage[fileName];
      for (const lineNumber in fileCoverageData.lineMap) {
        const lineCoverageData = fileCoverageData.lineMap[lineNumber];
        if (lineCoverageData.hits > 0) {
          coveredLines += 1;
        } else {
          uncoveredLines += 1;
        }
      }
    }
    let overallLineCoverageRate = 1;
    if (coveredLines + uncoveredLines > 0) {
      overallLineCoverageRate = parseFloat((coveredLines / (coveredLines + uncoveredLines) * 100).toFixed(4));
    }
    return {
      coveredLines,
      uncoveredLines,
      overallLineCoverageRate
    };
  };

  Utils.prototype.resolveFilePath = function(filePath) {
    if (filePath.length === 0) {
      return filePath;
    }
    if (filePath[0] === '~') {
      return path.join(process.env.HOME, filePath.slice(1));
    }
    if (filePath[0] !== '/') {
      return path.join(process.cwd(), filePath);
    }
    return filePath;
  };

  Utils.prototype.getCoverageFilePath = function(coverageFilePath, caseInsensitive) {
    if (caseInsensitive) {
      return coverageFilePath.toLowerCase();
    }
    return coverageFilePath;
  };

  module.exports.Utils = new Utils();
})();
